==> directory_constants-17.0.0-py3-none-any.whl: directory_constants/slugs.py <==
COMPONENTS_BANNER_DOMESTIC = 'eu-exit-banner-domestic'
COMPONENTS_BANNER_INTERNATIONAL = 'eu-exit-banner-international'

EUEXIT_DOMESTIC_NEWS = 'eu-exit-news'
EUEXIT_INTERNATIONAL_NEWS = 'international-eu-exit-news'
EUEXIT_DOMESTIC_FORM = 'eu-exit-domestic'
EUEXIT_FORM_SUCCESS = 'eu-exit-form-success'
EUEXIT_INTERNATIONAL_FORM = 'eu-exit-international'

FIND_A_SUPPLIER_INDUSTRY_LANDING = 'industries-landing-page'
FIND_A_SUPPLIER_LANDING = 'landing-page'
FIND_A_SUPPLIER_INDUSTRY_CONTACT = 'industry-contact'

GREAT_GET_FINANCE = 'get-finance'
GREAT_ADVICE = 'advice'
GREAT_HOME = 'home'
GREAT_HOME_INTERNATIONAL = 'international'
GREAT_MARKETING_PAGES = 'export-readiness-marketing-pages'
GREAT_PRIVACY_AND_COOKIES = 'privacy-and-cookies'
GREAT_SITE_POLICY_PAGES = 'export-readiness-site-policy-pages'
GREAT_TERMS_AND_CONDITIONS = 'terms-and-conditions'

HELP_ACCOUNT_COMPANY_NOT_FOUND = 'company-not-found'
HELP_ACCOUNT_SOLE_TRADER_ADDRESS_NOT_FOUND = 'sole-trader-address-not-found'
HELP_COMPANIES_HOUSE_LOGIN = 'companies-house-login'
HELP_EXOPP_ALERTS_IRRELEVANT = 'alerts-not-relevant'
HELP_EXOPPS_NO_RESPONSE = 'opportunity-no-response'
HELP_EXPORTING_TO_UK = 'exporting-to-the-uk'
HELP_FORM_SUCCESS = 'contact-success-form'
HELP_FORM_SUCCESS_BEIS = 'contact-beis-success'
HELP_FORM_SUCCESS_DEFRA = 'contact-defra-success'
HELP_FORM_SUCCESS_DSO = 'contact-dso-success-form'
HELP_FORM_SUCCESS_EVENTS = 'contact-events-success-form'
HELP_FORM_SUCCESS_EXPORT_ADVICE = 'contact-export-advice-success-form'
HELP_FORM_SUCCESS_FEEDBACK = 'contact-feedback-success-form'
HELP_FORM_SUCCESS_FIND_COMPANIES = 'contact-find-companies-success-form'
HELP_FORM_SUCCESS_INTERNATIONAL = 'contact-international-success-form'
HELP_FORM_SUCCESS_SOO = 'contact-soo-success-form'
HELP_MISSING_VERIFY_EMAIL = 'no-verification-email'
HELP_PASSWORD_RESET = 'password-reset'
HELP_VERIFICATION_CODE_ENTER = 'verification-letter-code'
HELP_VERIFICATION_CODE_LETTER = 'no-verification-letter'
HELP_VERIFICATION_CODE_MISSING = 'verification-missing'

INTERNATIONAL_MARKETING_PAGES = 'great-international-marketing-pages'
INTERNATIONAL_UK_HQ_PAGES = 'great-international-uk-hq-pages'

INVEST_SECTOR_LANDING_PAGE = 'sector-landing-page'
INVEST_GUIDE_LANDING_PAGE = 'setup-guide-landing-page'
INVEST_HIGH_POTENTIAL_OPPORTUNITY_FORM = 'high-potential-opportunity-form'
INVEST_HIGH_POTENTIAL_OPPORTUNITY_FORM_SUCCESS = (
    'high-potential-opportunity-submit-success'
)
INVEST_UK_REGION_LANDING_PAGE = 'uk-region-landing-page'
INVEST_HOME_PAGE = 'home-page'

PERFORMANCE_DASHBOARD = 'performance-dashboard'
PERFORMANCE_DASHBOARD_EXOPPS = 'performance-dashboard-export-opportunities'
PERFORMANCE_DASHBOARD_INVEST = 'performance-dashboard-invest'
PERFORMANCE_DASHBOARD_NOTES = 'performance-dashboard-notes'
PERFORMANCE_DASHBOARD_SOO = 'performance-dashboard-selling-online-overseas'
PERFORMANCE_DASHBOARD_TRADE_PROFILE = 'performance-dashboard-trade-profiles'

==> directory_constants-18.1.1-py3-none-any.whl: directory_constants/slugs.py <==
COMPONENTS_BANNER_DOMESTIC = 'eu-exit-banner-domestic'
COMPONENTS_BANNER_INTERNATIONAL = 'eu-exit-banner-international'

EUEXIT_DOMESTIC_NEWS = 'eu-exit-news'
EUEXIT_INTERNATIONAL_NEWS = 'international-eu-exit-news'
EUEXIT_DOMESTIC_FORM = 'eu-exit-domestic'
EUEXIT_FORM_SUCCESS = 'eu-exit-form-success'
EUEXIT_INTERNATIONAL_FORM = 'eu-exit-international'

FIND_A_SUPPLIER_INDUSTRY_LANDING = 'industries-landing-page'
FIND_A_SUPPLIER_LANDING = 'landing-page'
FIND_A_SUPPLIER_INDUSTRY_CONTACT = 'industry-contact'

GREAT_GET_FINANCE = 'get-finance'
GREAT_ADVICE = 'advice'
GREAT_HOME = 'great-domestic-home'
GREAT_HOME_OLD = 'home'
GREAT_HOME_INTERNATIONAL = 'great-international-home'
GREAT_HOME_INTERNATIONAL_OLD = 'international'
GREAT_MARKETING_PAGES = 'export-readiness-marketing-pages'
GREAT_PRIVACY_AND_COOKIES = 'privacy-and-cookies'
GREAT_SITE_POLICY_PAGES = 'export-readiness-site-policy-pages'
GREAT_TERMS_AND_CONDITIONS = 'terms-and-conditions'

HELP_ACCOUNT_COMPANY_NOT_FOUND = 'company-not-found'
HELP_ACCOUNT_SOLE_TRADER_ADDRESS_NOT_FOUND = 'sole-trader-address-not-found'
HELP_COMPANIES_HOUSE_LOGIN = 'companies-house-login'
HELP_EXOPP_ALERTS_IRRELEVANT = 'alerts-not-relevant'
HELP_EXOPPS_NO_RESPONSE = 'opportunity-no-response'
HELP_EXPORTING_TO_UK = 'exporting-to-the-uk'
HELP_FORM_SUCCESS = 'contact-success-form'
HELP_FORM_SUCCESS_BEIS = 'contact-beis-success'
HELP_FORM_SUCCESS_DEFRA = 'contact-defra-success'
HELP_FORM_SUCCESS_DSO = 'contact-dso-success-form'
HELP_FORM_SUCCESS_EVENTS = 'contact-events-success-form'
HELP_FORM_SUCCESS_EXPORT_ADVICE = 'contact-export-advice-success-form'
HELP_FORM_SUCCESS_FEEDBACK = 'contact-feedback-success-form'
HELP_FORM_SUCCESS_FIND_COMPANIES = 'contact-find-companies-success-form'
HELP_FORM_SUCCESS_INTERNATIONAL = 'contact-international-success-form'
HELP_FORM_SUCCESS_SOO = 'contact-soo-success-form'
HELP_MISSING_VERIFY_EMAIL = 'no-verification-email'
HELP_PASSWORD_RESET = 'password-reset'
HELP_VERIFICATION_CODE_ENTER = 'verification-letter-code'
HELP_VERIFICATION_CODE_LETTER = 'no-verification-letter'
HELP_VERIFICATION_CODE_MISSING = 'verification-missing'

INTERNATIONAL_MARKETING_PAGES = 'great-international-marketing-pages'
INTERNATIONAL_UK_HQ_PAGES = 'great-international-uk-hq-pages'

INVEST_SECTOR_LANDING_PAGE = 'sector-landing-page'
INVEST_GUIDE_LANDING_PAGE = 'setup-guide-landing-page'
INVEST_HIGH_POTENTIAL_OPPORTUNITY_FORM = 'high-potential-opportunity-form'
INVEST_HIGH_POTENTIAL_OPPORTUNITY_FORM_SUCCESS = (
    'high-potential-opportunity-submit-success'
)
INVEST_UK_REGION_LANDING_PAGE = 'uk-region-landing-page'
INVEST_HOME_PAGE = 'home-page'

PERFORMANCE_DASHBOARD = 'performance-dashboard'
PERFORMANCE_DASHBOARD_EXOPPS = 'performance-dashboard-export-opportunities'
PERFORMANCE_DASHBOARD_INVEST = 'performance-dashboard-invest'
PERFORMANCE_DASHBOARD_NOTES = 'performance-dashboard-notes'
PERFORMANCE_DASHBOARD_SOO = 'performance-dashboard-selling-online-overseas'
PERFORMANCE_DASHBOARD_TRADE_PROFILE = 'performance-dashboard-trade-profiles'
